/************************************************************************
 *   IRC - Internet Relay Chat, doc/example_module.c
 *   Copyright (C) 2001 Hybrid Development Team
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   $Id: m_rules.c,v 1.1.1.1 2003/08/17 19:36:54 jeremy Exp $
 */

/* List of ircd includes from ../include/ */
#include "stdinc.h"
#include "handlers.h"
#include "client.h"
#include "common.h"     /* FALSE bleah */
#include "ircd.h"
#include "irc_string.h"
#include "numeric.h"
#include "fdlist.h"
#include "s_bsd.h"
#include "s_conf.h"
#include "s_log.h"
#include "s_serv.h"
#include "send.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"

static void m_rules(struct Client *client_p, struct Client *source_p,
                     int parc, char *parv[]);
static void mo_rules(struct Client *client_p, struct Client *source_p,
                     int parc, char *parv[]);

struct Message rules_msgtab = {
  "RULES", 0, 0, 0, 1, MFLG_SLOW, 0,
  {m_unregistered, m_rules, mo_rules, mo_rules}
};

#ifndef STATIC_MODULES
void
_modinit(void)
{
  mod_add_cmd(&rules_msgtab);
}

void
_moddeinit(void)
{
  mod_del_cmd(&rules_msgtab);
}

const char *_version = "$Revision: 1.1.1.1 $";
#endif

/*
 * m_rules
 *      parv[0] = sender prefix
 *      parv[1] = parameter
 */
static void m_rules(struct Client *client_p, struct Client *source_p,
                   int parc, char *parv[])
{
  static time_t last_used = 0;

  if((last_used + ConfigFileEntry.pace_wait) > CurrentTime)
    {
      sendto_one(source_p,form_str(RPL_LOAD2HI),me.name,source_p->name);
      return;
  }
  else
    last_used = CurrentTime;

  if(!ConfigServerHide.disable_remote)
    {
      if (hunt_server(client_p,source_p, ":%s RULES :%s", 1,parc,parv)!=HUNTED_ISME)
      return;
    }

  SendMessageFile(source_p,&ConfigFileEntry.rules);
}

/*
** mo_rules
**      parv[0] = sender prefix
**      parv[1] = servername
*/
static void mo_rules(struct Client *client_p, struct Client *source_p,
                    int parc, char *parv[])
{
  if(IsServer(source_p))
    return;

  if (hunt_server(client_p, source_p, ":%s RULES :%s", 1,parc,parv)!=HUNTED_ISME)
    return;

  SendMessageFile(source_p,&ConfigFileEntry.rules);
}
