/*
 *  FreeWorld-ircd: an advanced Internet Relay Chat Daemon(ircd).
 *  m_services.c: Service shortcuts.
 *
 *  Copyright (C) 2002 by the past and present ircd coders, and others.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: m_services.c,v 1.1.1.1 2003/08/17 19:36:54 jeremy Exp $
 */


#include "stdinc.h"
#include "whowas.h"
#include "handlers.h"
#include "client.h" 
#include "common.h"
#include "hash.h"
#include "irc_string.h"
#include "ircd.h"
#include "ircd_defs.h"
#include "numeric.h"
#include "s_serv.h" 
#include "s_user.h"
#include "send.h"
#include "s_conf.h" 
#include "msg.h"
#include "parse.h"
#include "modules.h"

#define NickServ_NICK "NickServ"
#define NickServ_USER "NickServ@services.freeworld.nu"

#define ChanServ_NICK "ChanServ"
#define ChanServ_USER "ChanServ@services.freeworld.nu"

#define OperServ_NICK "OperServ"
#define OperServ_USER "OperServ@services.freeworld.nu"

#define MemoServ_NICK "MemoServ"
#define MemoServ_USER "MemoServ@services.freeworld.nu"

#define SeenServ_NICK "SeenServ"
#define SeenServ_USER "SeenServ@services.freeworld.nu"

#define HelpServ_NICK "HelpServ"
#define HelpServ_USER "HelpServ@services.freeworld.nu"

#define Global_NICK "Greeter"
#define Global_USER "Greeter@services.freeworld.nu"

static void m_NickServ (struct Client *source_p, struct Client *client_p, int parc, char *parv[]);
static void m_ChanServ (struct Client *source_p, struct Client *client_p, int parc, char *parv[]);
static void m_OperServ (struct Client *source_p, struct Client *client_p, int parc, char *parv[]);
static void m_MemoServ (struct Client *source_p, struct Client *client_p, int parc, char *parv[]);
static void m_SeenServ (struct Client *source_p, struct Client *client_p, int parc, char *parv[]);
static void m_HelpServ (struct Client *source_p, struct Client *client_p, int parc, char *parv[]);
static void m_Global   (struct Client *source_p, struct Client *client_p, int parc, char *parv[]);


struct Message NickServ_msgtab = {
  "NickServ", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_NickServ, m_ignore, m_NickServ}
};
struct Message ChanServ_msgtab = {
  "ChanServ", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_ChanServ, m_ignore, m_ChanServ}
};
struct Message OperServ_msgtab = {
  "OperServ", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_OperServ, m_ignore, m_OperServ}
};
struct Message MemoServ_msgtab = {
  "MemoServ", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_MemoServ, m_ignore, m_MemoServ}
};
struct Message SeenServ_msgtab = {
  "SeenServ", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_SeenServ, m_ignore, m_SeenServ}
};
struct Message HelpServ_msgtab = {
  "HelpServ", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_HelpServ, m_ignore, m_HelpServ}
};
struct Message Global_msgtab = {
  "Greeter", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_Global, m_ignore, m_Global}
};


struct Message NS_msgtab = {
  "NS", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_NickServ, m_ignore, m_NickServ}
};
struct Message CS_msgtab = {
  "CS", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_ChanServ, m_ignore, m_ChanServ}
};
struct Message OS_msgtab = {
  "OS", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_OperServ, m_ignore, m_OperServ}
};
struct Message MS_msgtab = {
  "MS", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_MemoServ, m_ignore, m_MemoServ}
};
struct Message SS_msgtab = {
  "SS", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_SeenServ, m_ignore, m_SeenServ}
};
struct Message HS_msgtab = {
  "HS", 0, 0, 1, 0, MFLG_SLOW, 0,
  {m_unregistered, m_HelpServ, m_ignore, m_HelpServ}
};


#ifndef STATIC_MODULES
void
_modinit(void)
{
mod_add_cmd(&NickServ_msgtab);
mod_add_cmd(&ChanServ_msgtab);
mod_add_cmd(&OperServ_msgtab);
mod_add_cmd(&MemoServ_msgtab);
mod_add_cmd(&SeenServ_msgtab);
mod_add_cmd(&HelpServ_msgtab);
mod_add_cmd(&Global_msgtab);

mod_add_cmd(&NS_msgtab);
mod_add_cmd(&CS_msgtab);
mod_add_cmd(&OS_msgtab);
mod_add_cmd(&MS_msgtab);
mod_add_cmd(&SS_msgtab);
mod_add_cmd(&HS_msgtab);
}

void
_moddeinit(void)
{
mod_del_cmd(&NickServ_msgtab);
mod_del_cmd(&ChanServ_msgtab);
mod_del_cmd(&OperServ_msgtab);
mod_del_cmd(&MemoServ_msgtab);
mod_del_cmd(&SeenServ_msgtab);
mod_del_cmd(&HelpServ_msgtab);
mod_del_cmd(&Global_msgtab);

mod_del_cmd(&NS_msgtab);
mod_del_cmd(&CS_msgtab);
mod_del_cmd(&OS_msgtab);
mod_del_cmd(&MS_msgtab);
mod_del_cmd(&SS_msgtab);
mod_del_cmd(&HS_msgtab);
}

const char *_version = "$Revision: 1.1.1.1 $";
#endif

static void
m_NickServ(struct Client *source_p, struct Client *client_p, int parc, char *parv[])
{
  struct Client *target_p;
  char sendstr[BUFSIZE];
  int i;

  sendstr[0] = '\0';

  if (parc<2 || *parv[1] == '\0')
    {
      sendto_one(source_p, form_str(ERR_NOTEXTTOSEND), me.name, parv[0]);
      return;
    }

  for(i=1; i < parc; i++)
    {
      if(i > 1)
        strlcat(sendstr, " ", sizeof(sendstr));
      strlcat(sendstr, parv[i], sizeof(sendstr));
    }

  if ((target_p = find_person(NickServ_NICK)))
    {
      sendto_one(target_p, ":%s PRIVMSG %s :%s", parv[0], NickServ_NICK, sendstr);
      return;
    }

  else
    {
      sendto_one(source_p, form_str(ERR_NOSUCHNICK), me.name, parv[0], NickServ_NICK);
      return;
    }
};

static void
m_ChanServ(struct Client *source_p, struct Client *client_p, int parc, char *parv[])
{
  struct Client *target_p;
  char sendstr[BUFSIZE];
  int i;
  
  sendstr[0] = '\0';
  
  if (parc<2 || *parv[1] == '\0')
    {
      sendto_one(source_p, form_str(ERR_NOTEXTTOSEND), me.name, parv[0]);
      return; 
    }

  for(i=1; i < parc; i++)
    {
      if(i > 1)
        strlcat(sendstr, " ", sizeof(sendstr));
      strlcat(sendstr, parv[i], sizeof(sendstr));
    }
 
  if ((target_p = find_person(ChanServ_NICK)))
    {
      sendto_one(target_p, ":%s PRIVMSG %s :%s", parv[0], ChanServ_NICK, sendstr);
      return;
    }

  else
    {
      sendto_one(source_p, form_str(ERR_NOSUCHNICK), me.name, parv[0], ChanServ_NICK);
      return;
    }
};

static void
m_OperServ(struct Client *source_p, struct Client *client_p, int parc, char *parv[])
{
  struct Client *target_p;
  char sendstr[BUFSIZE];
  int i;
  
  sendstr[0] = '\0';
  
  if (parc<2 || *parv[1] == '\0')
    {
      sendto_one(source_p, form_str(ERR_NOTEXTTOSEND), me.name, parv[0]);
      return; 
    }

  for(i=1; i < parc; i++)
    {
      if(i > 1)
        strlcat(sendstr, " ", sizeof(sendstr));
      strlcat(sendstr, parv[i], sizeof(sendstr));
    }
 
  if ((target_p = find_person(OperServ_NICK)))
    {
      sendto_one(target_p, ":%s PRIVMSG %s :%s", parv[0], OperServ_NICK, sendstr);
      return;
    }

  else
    {
      sendto_one(source_p, form_str(ERR_NOSUCHNICK), me.name, parv[0], OperServ_NICK);
      return;
    }
};

static void
m_MemoServ(struct Client *source_p, struct Client *client_p, int parc, char *parv[])
{
  struct Client *target_p;
  char sendstr[BUFSIZE];
  int i;
  
  sendstr[0] = '\0';
  
  if (parc<2 || *parv[1] == '\0')
    {
      sendto_one(source_p, form_str(ERR_NOTEXTTOSEND), me.name, parv[0]);
      return; 
    }

  for(i=1; i < parc; i++)
    {
      if(i > 1)
        strlcat(sendstr, " ", sizeof(sendstr));
      strlcat(sendstr, parv[i], sizeof(sendstr));
    }
 
  if ((target_p = find_person(MemoServ_NICK)))
    {
      sendto_one(target_p, ":%s PRIVMSG %s :%s", parv[0], MemoServ_NICK, sendstr);
      return;
    }

  else
    {
      sendto_one(source_p, form_str(ERR_NOSUCHNICK), me.name, parv[0], MemoServ_NICK);
      return;
    }
};

static void
m_SeenServ(struct Client *source_p, struct Client *client_p, int parc, char *parv[])
{
  struct Client *target_p;
  char sendstr[BUFSIZE];
  int i;
  
  sendstr[0] = '\0';
  
  if (parc<2 || *parv[1] == '\0')
    {
      sendto_one(source_p, form_str(ERR_NOTEXTTOSEND), me.name, parv[0]);
      return; 
    }

  for(i=1; i < parc; i++)
    {
      if(i > 1)
        strlcat(sendstr, " ", sizeof(sendstr));
      strlcat(sendstr, parv[i], sizeof(sendstr));
    }
 
  if ((target_p = find_person(SeenServ_NICK)))
    {
      sendto_one(target_p, ":%s PRIVMSG %s :%s", parv[0], SeenServ_NICK, sendstr);
      return;
    }

  else
    {
      sendto_one(source_p, form_str(ERR_NOSUCHNICK), me.name, parv[0], SeenServ_NICK);
      return;
    }
};

static void
m_Global(struct Client *source_p, struct Client *client_p, int parc, char *parv[])
{
  struct Client *target_p;
  char sendstr[BUFSIZE];
  int i;
  
  sendstr[0] = '\0';
  
  if (parc<2 || *parv[1] == '\0')
    {
      sendto_one(source_p, form_str(ERR_NOTEXTTOSEND), me.name, parv[0]);
      return; 
    }

  for(i=1; i < parc; i++)
    {
      if(i > 1)
        strlcat(sendstr, " ", sizeof(sendstr));
      strlcat(sendstr, parv[i], sizeof(sendstr));
    }
 
  if ((target_p = find_person(Global_NICK)))
    {
      sendto_one(target_p, ":%s PRIVMSG %s :%s", parv[0], Global_NICK, sendstr);
      return;
    }

  else
    {
      sendto_one(source_p, form_str(ERR_NOSUCHNICK), me.name, parv[0], Global_NICK);
      return;
    }
};

static void
m_HelpServ(struct Client *source_p, struct Client *client_p, int parc, char *parv[])
{
  struct Client *target_p;
  char sendstr[BUFSIZE];
  int i;
  
  sendstr[0] = '\0';
  
  if (parc<2 || *parv[1] == '\0')
    {
      sendto_one(source_p, form_str(ERR_NOTEXTTOSEND), me.name, parv[0]);
      return; 
    }

  for(i=1; i < parc; i++)
    {
      if(i > 1)
        strlcat(sendstr, " ", sizeof(sendstr));
      strlcat(sendstr, parv[i], sizeof(sendstr));
    }
 
  if ((target_p = find_person(HelpServ_NICK)))
    {
      sendto_one(target_p, ":%s PRIVMSG %s :%s", parv[0], HelpServ_NICK, sendstr);
      return;
    }

  else
    {
      sendto_one(source_p, form_str(ERR_NOSUCHNICK), me.name, parv[0], HelpServ_NICK);
      return;
    }
};
